@@ -175,169 +175,174 @@
 #include <pysideqflags.h>
 
 // Type indices
-#define SBK_QT3DRENDER_IDX                                           0
-#define SBK_QT3DRENDER_QTEXTUREDATA_IDX                              151
-#define SBK_QT3DRENDER_PROPERTYREADERINTERFACE_IDX                   1
-#define SBK_QT3DRENDER_QFRAMEGRAPHNODECREATEDCHANGEBASE_IDX          55
-#define SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                         155
-#define SBK_QT3DRENDER_QRAYCASTERHIT_IDX                             99
-#define SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX                     100
-#define SBK_QT3DRENDER_QABSTRACTFUNCTOR_IDX                          2
-#define SBK_QT3DRENDER_QTEXTUREGENERATOR_IDX                         152
-#define SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX                156
-#define SBK_QT3DRENDER_QGEOMETRYFACTORY_IDX                          60
-#define SBK_QT3DRENDER_QBUFFERDATAGENERATOR_IDX                      33
-#define SBK_QT3DRENDER_QLEVELOFDETAILBOUNDINGSPHERE_IDX              70
-#define SBK_QT3DRENDER_QPICKEVENT_IDX                                83
-#define SBK_QT3DRENDER_QPICKEVENT_BUTTONS_IDX                        84
-#define SBK_QT3DRENDER_QPICKEVENT_MODIFIERS_IDX                      85
-#define SBK_QT3DRENDER_QPICKTRIANGLEEVENT_IDX                        88
-#define SBK_QT3DRENDER_QPICKPOINTEVENT_IDX                           87
-#define SBK_QT3DRENDER_QPICKLINEEVENT_IDX                            86
-#define SBK_QT3DRENDER_QPICKINGSETTINGS_IDX                          89
-#define SBK_QT3DRENDER_QPICKINGSETTINGS_PICKMETHOD_IDX               91
-#define SBK_QT3DRENDER_QPICKINGSETTINGS_PICKRESULTMODE_IDX           92
-#define SBK_QT3DRENDER_QPICKINGSETTINGS_FACEORIENTATIONPICKINGMODE_IDX 90
-#define SBK_QT3DRENDER_QPARAMETER_IDX                                82
-#define SBK_QT3DRENDER_QCAMERA_IDX                                   34
-#define SBK_QT3DRENDER_QCAMERA_CAMERATRANSLATIONOPTION_IDX           35
-#define SBK_QT3DRENDER_QTECHNIQUE_IDX                                139
-#define SBK_QT3DRENDER_QBUFFER_IDX                                   28
-#define SBK_QT3DRENDER_QBUFFER_BUFFERTYPE_IDX                        30
-#define SBK_QT3DRENDER_QBUFFER_USAGETYPE_IDX                         31
-#define SBK_QT3DRENDER_QBUFFER_ACCESSTYPE_IDX                        29
-#define SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                       113
-#define SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX       114
-#define SBK_QT3DRENDER_QFRAMEGRAPHNODE_IDX                           54
-#define SBK_QT3DRENDER_QPROXIMITYFILTER_IDX                          97
-#define SBK_QT3DRENDER_QCLEARBUFFERS_IDX                             39
-#define SBK_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE_IDX                  40
-#define SBK_QT3DRENDER_QCAMERASELECTOR_IDX                           38
-#define SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                          140
-#define SBK_QT3DRENDER_QBUFFERCAPTURE_IDX                            32
-#define SBK_QT3DRENDER_QNODRAW_IDX                                   79
-#define SBK_QT3DRENDER_QBLITFRAMEBUFFER_IDX                          27
-#define SBK_QT3DRENDER_QMEMORYBARRIER_IDX                            74
-#define SBK_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX                  75
-#define SBK_QT3DRENDER_QSORTPOLICY_IDX                               127
-#define SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                      128
-#define SBK_QT3DRENDER_QLAYERFILTER_IDX                              67
-#define SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                     115
-#define SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                    111
-#define SBK_QT3DRENDER_QRENDERSTATESET_IDX                           110
-#define SBK_QT3DRENDER_QFRUSTUMCULLING_IDX                           58
-#define SBK_QT3DRENDER_QVIEWPORT_IDX                                 161
-#define SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                         106
-#define SBK_QT3DRENDER_QRENDERCAPTURE_IDX                            103
-#define SBK_QT3DRENDER_QDISPATCHCOMPUTE_IDX                          49
-#define SBK_QT3DRENDER_QATTRIBUTE_IDX                                20
-#define SBK_QT3DRENDER_QATTRIBUTE_ATTRIBUTETYPE_IDX                  21
-#define SBK_QT3DRENDER_QATTRIBUTE_VERTEXBASETYPE_IDX                 22
-#define SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                     126
-#define SBK_QT3DRENDER_QSHADERDATA_IDX                               122
-#define SBK_QT3DRENDER_QMATERIAL_IDX                                 73
-#define SBK_QT3DRENDER_QLEVELOFDETAIL_IDX                            68
-#define SBK_QT3DRENDER_QLEVELOFDETAIL_THRESHOLDTYPE_IDX              69
-#define SBK_QT3DRENDER_QLEVELOFDETAILSWITCH_IDX                      71
-#define SBK_QT3DRENDER_QSCENELOADER_IDX                              116
-#define SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                       118
-#define SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX                117
-#define SBK_QT3DRENDER_QCOMPUTECOMMAND_IDX                           43
-#define SBK_QT3DRENDER_QRENDERTARGET_IDX                             112
-#define SBK_QT3DRENDER_QLAYER_IDX                                    66
-#define SBK_QT3DRENDER_QGEOMETRYRENDERER_IDX                         61
-#define SBK_QT3DRENDER_QGEOMETRYRENDERER_PRIMITIVETYPE_IDX           62
-#define SBK_QT3DRENDER_QMESH_IDX                                     76
-#define SBK_QT3DRENDER_QRENDERSETTINGS_IDX                           107
-#define SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX              108
-#define SBK_QT3DRENDER_QOBJECTPICKER_IDX                             80
-#define SBK_QT3DRENDER_QCAMERALENS_IDX                               36
-#define SBK_QT3DRENDER_QCAMERALENS_PROJECTIONTYPE_IDX                37
-#define SBK_QT3DRENDER_QABSTRACTRAYCASTER_IDX                        5
-#define SBK_QT3DRENDER_QABSTRACTRAYCASTER_RUNMODE_IDX                7
-#define SBK_QT3DRENDER_QABSTRACTRAYCASTER_FILTERMODE_IDX             6
-#define SBK_QT3DRENDER_QRAYCASTER_IDX                                98
-#define SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                          120
-#define SBK_QT3DRENDER_QABSTRACTLIGHT_IDX                            3
-#define SBK_QT3DRENDER_QABSTRACTLIGHT_TYPE_IDX                       4
-#define SBK_QT3DRENDER_QDIRECTIONALLIGHT_IDX                         48
-#define SBK_QT3DRENDER_QPOINTLIGHT_IDX                               93
-#define SBK_QT3DRENDER_QSPOTLIGHT_IDX                                129
-#define SBK_QT3DRENDER_QENVIRONMENTLIGHT_IDX                         52
-#define SBK_QT3DRENDER_QRENDERSTATE_IDX                              109
-#define SBK_QT3DRENDER_QDEPTHTEST_IDX                                46
-#define SBK_QT3DRENDER_QDEPTHTEST_DEPTHFUNCTION_IDX                  47
-#define SBK_QT3DRENDER_QPOLYGONOFFSET_IDX                            96
-#define SBK_QT3DRENDER_QCULLFACE_IDX                                 44
-#define SBK_QT3DRENDER_QCULLFACE_CULLINGMODE_IDX                     45
-#define SBK_QT3DRENDER_QPOINTSIZE_IDX                                94
-#define SBK_QT3DRENDER_QPOINTSIZE_SIZEMODE_IDX                       95
-#define SBK_QT3DRENDER_QCOLORMASK_IDX                                42
-#define SBK_QT3DRENDER_QCLIPPLANE_IDX                                41
-#define SBK_QT3DRENDER_QSTENCILTEST_IDX                              135
-#define SBK_QT3DRENDER_QNODEPTHMASK_IDX                              78
-#define SBK_QT3DRENDER_QSTENCILOPERATION_IDX                         131
-#define SBK_QT3DRENDER_QMULTISAMPLEANTIALIASING_IDX                  77
-#define SBK_QT3DRENDER_QSTENCILMASK_IDX                              130
-#define SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_IDX                   25
-#define SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_BLENDING_IDX          26
-#define SBK_QT3DRENDER_QBLENDEQUATION_IDX                            23
-#define SBK_QT3DRENDER_QBLENDEQUATION_BLENDFUNCTION_IDX              24
-#define SBK_QT3DRENDER_QLINEWIDTH_IDX                                72
-#define SBK_QT3DRENDER_QALPHATEST_IDX                                18
-#define SBK_QT3DRENDER_QALPHATEST_ALPHAFUNCTION_IDX                  19
-#define SBK_QT3DRENDER_QALPHACOVERAGE_IDX                            17
-#define SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                          121
-#define SBK_QT3DRENDER_QSCISSORTEST_IDX                              119
-#define SBK_QT3DRENDER_QFRONTFACE_IDX                                56
-#define SBK_QT3DRENDER_QFRONTFACE_WINDINGDIRECTION_IDX               57
-#define SBK_QT3DRENDER_QDITHERING_IDX                                50
-#define SBK_QT3DRENDER_QABSTRACTTEXTUREIMAGE_IDX                     16
-#define SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                             153
-#define SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                      154
-#define SBK_QT3DRENDER_QPAINTEDTEXTUREIMAGE_IDX                      81
-#define SBK_QT3DRENDER_QABSTRACTTEXTURE_IDX                          8
-#define SBK_QT3DRENDER_QABSTRACTTEXTURE_STATUS_IDX                   13
-#define SBK_QT3DRENDER_QABSTRACTTEXTURE_TARGET_IDX                   14
-#define SBK_QT3DRENDER_QABSTRACTTEXTURE_TEXTUREFORMAT_IDX            15
-#define SBK_QT3DRENDER_QABSTRACTTEXTURE_FILTER_IDX                   12
-#define SBK_QT3DRENDER_QABSTRACTTEXTURE_CUBEMAPFACE_IDX              11
-#define SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONFUNCTION_IDX       9
-#define SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONMODE_IDX           10
-#define SBK_QT3DRENDER_QTEXTURE3D_IDX                                147
-#define SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                           144
-#define SBK_QT3DRENDER_QTEXTURE2D_IDX                                143
-#define SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                           142
-#define SBK_QT3DRENDER_QTEXTURE1D_IDX                                141
-#define SBK_QT3DRENDER_QTEXTURELOADER_IDX                            157
-#define SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                            148
-#define SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                         158
-#define SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX                146
-#define SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                     145
-#define SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                      150
-#define SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                           149
-#define SBK_QT3DRENDER_QGEOMETRY_IDX                                 59
-#define SBK_QT3DRENDER_QRENDERPASS_IDX                               105
-#define SBK_QT3DRENDER_QFILTERKEY_IDX                                53
-#define SBK_QT3DRENDER_QSHADERPROGRAM_IDX                            123
-#define SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX                 124
-#define SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                     125
-#define SBK_QT3DRENDER_QEFFECT_IDX                                   51
-#define SBK_QT3DRENDER_QRENDERASPECT_IDX                             101
-#define SBK_QT3DRENDER_QRENDERASPECT_RENDERTYPE_IDX                  102
-#define SBK_QT3DRENDER_QGRAPHICSAPIFILTER_IDX                        63
-#define SBK_QT3DRENDER_QGRAPHICSAPIFILTER_API_IDX                    64
-#define SBK_QT3DRENDER_QGRAPHICSAPIFILTER_OPENGLPROFILE_IDX          65
-#define SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                          159
-#define SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX                 160
-#define SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                     136
-#define SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX     137
-#define SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX     138
-#define SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX                132
-#define SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX       133
-#define SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX      134
-#define SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                       104
-#define SBK_Qt3DRender_IDX_COUNT                                     162
+#define SBK_QT3DRENDER_IDX                                           2
+#define SBK_QT3DRENDER_QTEXTUREDATA_IDX                              159
+#define SBK_QT3DRENDER_PROPERTYREADERINTERFACE_IDX                   6
+#define SBK_QT3DRENDER_QFRAMEGRAPHNODECREATEDCHANGEBASE_IDX          61
+#define SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                         163
+#define SBK_QT3DRENDER_QRAYCASTERHIT_IDX                             107
+#define SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX                     108
+#define SBK_QT3DRENDER_QABSTRACTFUNCTOR_IDX                          7
+#define SBK_QT3DRENDER_QTEXTUREGENERATOR_IDX                         160
+#define SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX                164
+#define SBK_QT3DRENDER_QGEOMETRYFACTORY_IDX                          66
+#define SBK_QT3DRENDER_QBUFFERDATAGENERATOR_IDX                      39
+#define SBK_QT3DRENDER_QLEVELOFDETAILBOUNDINGSPHERE_IDX              77
+#define SBK_QT3DRENDER_QPICKEVENT_IDX                                91
+#define SBK_QT3DRENDER_QPICKEVENT_BUTTONS_IDX                        92
+#define SBK_QT3DRENDER_QPICKEVENT_MODIFIERS_IDX                      93
+#define SBK_QT3DRENDER_QPICKTRIANGLEEVENT_IDX                        96
+#define SBK_QT3DRENDER_QPICKPOINTEVENT_IDX                           95
+#define SBK_QT3DRENDER_QPICKLINEEVENT_IDX                            94
+#define SBK_QT3DRENDER_QPICKINGSETTINGS_IDX                          97
+#define SBK_QT3DRENDER_QPICKINGSETTINGS_PICKMETHOD_IDX               99
+#define SBK_QT3DRENDER_QPICKINGSETTINGS_PICKRESULTMODE_IDX           100
+#define SBK_QT3DRENDER_QPICKINGSETTINGS_FACEORIENTATIONPICKINGMODE_IDX 98
+#define SBK_QT3DRENDER_QPARAMETER_IDX                                90
+#define SBK_QT3DRENDER_QCAMERA_IDX                                   40
+#define SBK_QT3DRENDER_QCAMERA_CAMERATRANSLATIONOPTION_IDX           41
+#define SBK_QT3DRENDER_QTECHNIQUE_IDX                                147
+#define SBK_QT3DRENDER_QBUFFER_IDX                                   34
+#define SBK_QT3DRENDER_QBUFFER_BUFFERTYPE_IDX                        36
+#define SBK_QT3DRENDER_QBUFFER_USAGETYPE_IDX                         37
+#define SBK_QT3DRENDER_QBUFFER_ACCESSTYPE_IDX                        35
+#define SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                       121
+#define SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX       122
+#define SBK_QT3DRENDER_QFRAMEGRAPHNODE_IDX                           60
+#define SBK_QT3DRENDER_QPROXIMITYFILTER_IDX                          105
+#define SBK_QT3DRENDER_QCLEARBUFFERS_IDX                             45
+#define SBK_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE_IDX                  46
+#define SBK_QFLAGS_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE__IDX          0
+#define SBK_QT3DRENDER_QCAMERASELECTOR_IDX                           44
+#define SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                          148
+#define SBK_QT3DRENDER_QBUFFERCAPTURE_IDX                            38
+#define SBK_QT3DRENDER_QNODRAW_IDX                                   87
+#define SBK_QT3DRENDER_QBLITFRAMEBUFFER_IDX                          32
+#define SBK_QT3DRENDER_QBLITFRAMEBUFFER_INTERPOLATIONMETHOD_IDX      33
+#define SBK_QT3DRENDER_QMEMORYBARRIER_IDX                            81
+#define SBK_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX                  82
+#define SBK_QFLAGS_QT3DRENDER_QMEMORYBARRIER_OPERATION__IDX          1
+#define SBK_QT3DRENDER_QSORTPOLICY_IDX                               135
+#define SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                      136
+#define SBK_QT3DRENDER_QLAYERFILTER_IDX                              73
+#define SBK_QT3DRENDER_QLAYERFILTER_FILTERMODE_IDX                   74
+#define SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                     123
+#define SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                    119
+#define SBK_QT3DRENDER_QRENDERSTATESET_IDX                           118
+#define SBK_QT3DRENDER_QFRUSTUMCULLING_IDX                           64
+#define SBK_QT3DRENDER_QVIEWPORT_IDX                                 169
+#define SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                         114
+#define SBK_QT3DRENDER_QRENDERCAPTURE_IDX                            111
+#define SBK_QT3DRENDER_QDISPATCHCOMPUTE_IDX                          55
+#define SBK_QT3DRENDER_QATTRIBUTE_IDX                                25
+#define SBK_QT3DRENDER_QATTRIBUTE_ATTRIBUTETYPE_IDX                  26
+#define SBK_QT3DRENDER_QATTRIBUTE_VERTEXBASETYPE_IDX                 27
+#define SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                     134
+#define SBK_QT3DRENDER_QSHADERDATA_IDX                               130
+#define SBK_QT3DRENDER_QMATERIAL_IDX                                 80
+#define SBK_QT3DRENDER_QLEVELOFDETAIL_IDX                            75
+#define SBK_QT3DRENDER_QLEVELOFDETAIL_THRESHOLDTYPE_IDX              76
+#define SBK_QT3DRENDER_QLEVELOFDETAILSWITCH_IDX                      78
+#define SBK_QT3DRENDER_QSCENELOADER_IDX                              124
+#define SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                       126
+#define SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX                125
+#define SBK_QT3DRENDER_QCOMPUTECOMMAND_IDX                           49
+#define SBK_QT3DRENDER_QRENDERTARGET_IDX                             120
+#define SBK_QT3DRENDER_QLAYER_IDX                                    72
+#define SBK_QT3DRENDER_QGEOMETRYRENDERER_IDX                         67
+#define SBK_QT3DRENDER_QGEOMETRYRENDERER_PRIMITIVETYPE_IDX           68
+#define SBK_QT3DRENDER_QMESH_IDX                                     83
+#define SBK_QT3DRENDER_QMESH_STATUS_IDX                              84
+#define SBK_QT3DRENDER_QRENDERSETTINGS_IDX                           115
+#define SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX              116
+#define SBK_QT3DRENDER_QOBJECTPICKER_IDX                             88
+#define SBK_QT3DRENDER_QCAMERALENS_IDX                               42
+#define SBK_QT3DRENDER_QCAMERALENS_PROJECTIONTYPE_IDX                43
+#define SBK_QT3DRENDER_QABSTRACTRAYCASTER_IDX                        10
+#define SBK_QT3DRENDER_QABSTRACTRAYCASTER_RUNMODE_IDX                12
+#define SBK_QT3DRENDER_QABSTRACTRAYCASTER_FILTERMODE_IDX             11
+#define SBK_QT3DRENDER_QRAYCASTER_IDX                                106
+#define SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                          128
+#define SBK_QT3DRENDER_QABSTRACTLIGHT_IDX                            8
+#define SBK_QT3DRENDER_QABSTRACTLIGHT_TYPE_IDX                       9
+#define SBK_QT3DRENDER_QDIRECTIONALLIGHT_IDX                         54
+#define SBK_QT3DRENDER_QPOINTLIGHT_IDX                               101
+#define SBK_QT3DRENDER_QSPOTLIGHT_IDX                                137
+#define SBK_QT3DRENDER_QENVIRONMENTLIGHT_IDX                         58
+#define SBK_QT3DRENDER_QRENDERSTATE_IDX                              117
+#define SBK_QT3DRENDER_QDEPTHTEST_IDX                                52
+#define SBK_QT3DRENDER_QDEPTHTEST_DEPTHFUNCTION_IDX                  53
+#define SBK_QT3DRENDER_QPOLYGONOFFSET_IDX                            104
+#define SBK_QT3DRENDER_QCULLFACE_IDX                                 50
+#define SBK_QT3DRENDER_QCULLFACE_CULLINGMODE_IDX                     51
+#define SBK_QT3DRENDER_QPOINTSIZE_IDX                                102
+#define SBK_QT3DRENDER_QPOINTSIZE_SIZEMODE_IDX                       103
+#define SBK_QT3DRENDER_QCOLORMASK_IDX                                48
+#define SBK_QT3DRENDER_QCLIPPLANE_IDX                                47
+#define SBK_QT3DRENDER_QSTENCILTEST_IDX                              143
+#define SBK_QT3DRENDER_QNODEPTHMASK_IDX                              86
+#define SBK_QT3DRENDER_QSTENCILOPERATION_IDX                         139
+#define SBK_QT3DRENDER_QMULTISAMPLEANTIALIASING_IDX                  85
+#define SBK_QT3DRENDER_QSTENCILMASK_IDX                              138
+#define SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_IDX                   30
+#define SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_BLENDING_IDX          31
+#define SBK_QT3DRENDER_QBLENDEQUATION_IDX                            28
+#define SBK_QT3DRENDER_QBLENDEQUATION_BLENDFUNCTION_IDX              29
+#define SBK_QT3DRENDER_QLINEWIDTH_IDX                                79
+#define SBK_QT3DRENDER_QALPHATEST_IDX                                23
+#define SBK_QT3DRENDER_QALPHATEST_ALPHAFUNCTION_IDX                  24
+#define SBK_QT3DRENDER_QALPHACOVERAGE_IDX                            22
+#define SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                          129
+#define SBK_QT3DRENDER_QSCISSORTEST_IDX                              127
+#define SBK_QT3DRENDER_QFRONTFACE_IDX                                62
+#define SBK_QT3DRENDER_QFRONTFACE_WINDINGDIRECTION_IDX               63
+#define SBK_QT3DRENDER_QDITHERING_IDX                                56
+#define SBK_QT3DRENDER_QABSTRACTTEXTUREIMAGE_IDX                     21
+#define SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                             161
+#define SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                      162
+#define SBK_QT3DRENDER_QPAINTEDTEXTUREIMAGE_IDX                      89
+#define SBK_QT3DRENDER_QABSTRACTTEXTURE_IDX                          13
+#define SBK_QT3DRENDER_QABSTRACTTEXTURE_STATUS_IDX                   18
+#define SBK_QT3DRENDER_QABSTRACTTEXTURE_TARGET_IDX                   19
+#define SBK_QT3DRENDER_QABSTRACTTEXTURE_TEXTUREFORMAT_IDX            20
+#define SBK_QT3DRENDER_QABSTRACTTEXTURE_FILTER_IDX                   17
+#define SBK_QT3DRENDER_QABSTRACTTEXTURE_CUBEMAPFACE_IDX              16
+#define SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONFUNCTION_IDX       14
+#define SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONMODE_IDX           15
+#define SBK_QT3DRENDER_QTEXTURE3D_IDX                                155
+#define SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                           152
+#define SBK_QT3DRENDER_QTEXTURE2D_IDX                                151
+#define SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                           150
+#define SBK_QT3DRENDER_QTEXTURE1D_IDX                                149
+#define SBK_QT3DRENDER_QTEXTURELOADER_IDX                            165
+#define SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                            156
+#define SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                         166
+#define SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX                154
+#define SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                     153
+#define SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                      158
+#define SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                           157
+#define SBK_QT3DRENDER_QGEOMETRY_IDX                                 65
+#define SBK_QT3DRENDER_QRENDERPASS_IDX                               113
+#define SBK_QT3DRENDER_QFILTERKEY_IDX                                59
+#define SBK_QT3DRENDER_QSHADERPROGRAM_IDX                            131
+#define SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX                 132
+#define SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                     133
+#define SBK_QT3DRENDER_QEFFECT_IDX                                   57
+#define SBK_QT3DRENDER_QRENDERASPECT_IDX                             109
+#define SBK_QT3DRENDER_QRENDERASPECT_RENDERTYPE_IDX                  110
+#define SBK_QT3DRENDER_QGRAPHICSAPIFILTER_IDX                        69
+#define SBK_QT3DRENDER_QGRAPHICSAPIFILTER_API_IDX                    70
+#define SBK_QT3DRENDER_QGRAPHICSAPIFILTER_OPENGLPROFILE_IDX          71
+#define SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                          167
+#define SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX                 168
+#define SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                     144
+#define SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX     145
+#define SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX     146
+#define SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX                140
+#define SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX       141
+#define SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX      142
+#define SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                       112
+#define SBK_Qt3DRender_IDX_COUNT                                     170
 
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_Qt3DRenderTypes;
@@ -410,16 +415,20 @@ template<> inline PyTypeObject* SbkType< ::Qt3DRender::QRenderTargetOutput >() {
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QFrameGraphNode >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QFRAMEGRAPHNODE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QProximityFilter >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QPROXIMITYFILTER_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QClearBuffers::BufferType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QFlags<Qt3DRender::QClearBuffers::BufferType> >() { return SbkPySide2_Qt3DRenderTypes[SBK_QFLAGS_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE__IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QClearBuffers >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QCLEARBUFFERS_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QCameraSelector >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QCAMERASELECTOR_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QTechniqueFilter >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QBufferCapture >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QBUFFERCAPTURE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QNoDraw >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QNODRAW_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DRender::QBlitFramebuffer::InterpolationMethod >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QBLITFRAMEBUFFER_INTERPOLATIONMETHOD_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QBlitFramebuffer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QBLITFRAMEBUFFER_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QMemoryBarrier::Operation >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX]; }
+template<> inline PyTypeObject* SbkType< ::QFlags<Qt3DRender::QMemoryBarrier::Operation> >() { return SbkPySide2_Qt3DRenderTypes[SBK_QFLAGS_QT3DRENDER_QMEMORYBARRIER_OPERATION__IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QMemoryBarrier >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QMEMORYBARRIER_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QSortPolicy::SortType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QSortPolicy >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSORTPOLICY_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DRender::QLayerFilter::FilterMode >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QLAYERFILTER_FILTERMODE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QLayerFilter >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QLAYERFILTER_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QRenderTargetSelector >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QRenderSurfaceSelector >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX]); }
@@ -446,6 +455,7 @@ template<> inline PyTypeObject* SbkType< ::Qt3DRender::QRenderTarget >() { retur
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QLayer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QLAYER_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QGeometryRenderer::PrimitiveType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QGEOMETRYRENDERER_PRIMITIVETYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QGeometryRenderer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QGEOMETRYRENDERER_IDX]); }
+template<> inline PyTypeObject* SbkType< ::Qt3DRender::QMesh::Status >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QMESH_STATUS_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QMesh >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QMESH_IDX]); }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QRenderSettings::RenderPolicy >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX]; }
 template<> inline PyTypeObject* SbkType< ::Qt3DRender::QRenderSettings >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERSETTINGS_IDX]); }
