@@ -115,23 +115,25 @@
 #include <QVector>
 
 // Type indices
-#define SBK_QPLACEUSER_IDX                                           69
-#define SBK_QPLACESEARCHREQUEST_IDX                                  64
-#define SBK_QPLACESEARCHREQUEST_RELEVANCEHINT_IDX                    65
-#define SBK_QPLACEMATCHREQUEST_IDX                                   55
-#define SBK_QPLACESEARCHRESULT_IDX                                   66
-#define SBK_QPLACEPROPOSEDSEARCHRESULT_IDX                           56
-#define SBK_QPLACERESULT_IDX                                         61
-#define SBK_QPLACESUPPLIER_IDX                                       68
-#define SBK_QPLACECONTENTREQUEST_IDX                                 45
+#define SBK_QPLACEUSER_IDX                                           71
+#define SBK_QPLACESEARCHREQUEST_IDX                                  65
+#define SBK_QPLACESEARCHREQUEST_RELEVANCEHINT_IDX                    66
+#define SBK_QPLACEMATCHREQUEST_IDX                                   56
+#define SBK_QPLACESEARCHRESULT_IDX                                   67
+#define SBK_QPLACESEARCHRESULT_SEARCHRESULTTYPE_IDX                  68
+#define SBK_QPLACEPROPOSEDSEARCHRESULT_IDX                           57
+#define SBK_QPLACERESULT_IDX                                         62
+#define SBK_QPLACESUPPLIER_IDX                                       70
+#define SBK_QPLACECONTENTREQUEST_IDX                                 46
 #define SBK_QPLACE_IDX                                               39
 #define SBK_QPLACECONTACTDETAIL_IDX                                  42
 #define SBK_QPLACEATTRIBUTE_IDX                                      40
-#define SBK_QPLACERATINGS_IDX                                        57
+#define SBK_QPLACERATINGS_IDX                                        58
 #define SBK_QPLACECONTENT_IDX                                        43
-#define SBK_QPLACEREVIEW_IDX                                         62
-#define SBK_QPLACEIMAGE_IDX                                          51
-#define SBK_QPLACEEDITORIAL_IDX                                      47
+#define SBK_QPLACECONTENT_TYPE_IDX                                   44
+#define SBK_QPLACEREVIEW_IDX                                         63
+#define SBK_QPLACEIMAGE_IDX                                          52
+#define SBK_QPLACEEDITORIAL_IDX                                      48
 #define SBK_QPLACECATEGORY_IDX                                       41
 #define SBK_QGEOSERVICEPROVIDERFACTORY_IDX                           37
 #define SBK_QGEOSERVICEPROVIDERFACTORYV2_IDX                         38
@@ -152,7 +154,7 @@
 #define SBK_QFLAGS_QGEOROUTEREQUEST_MANEUVERDETAIL__IDX              2
 #define SBK_QGEOMANEUVER_IDX                                         15
 #define SBK_QGEOMANEUVER_INSTRUCTIONDIRECTION_IDX                    16
-#define SBK_QPLACEICON_IDX                                           48
+#define SBK_QPLACEICON_IDX                                           49
 #define SBK_QGEOSERVICEPROVIDER_IDX                                  30
 #define SBK_QGEOSERVICEPROVIDER_ERROR_IDX                            31
 #define SBK_QGEOSERVICEPROVIDER_ROUTINGFEATURE_IDX                   36
@@ -173,19 +175,19 @@
 #define SBK_QGEOCODINGMANAGER_IDX                                    13
 #define SBK_QGEOCODEREPLY_IDX                                        11
 #define SBK_QGEOCODEREPLY_ERROR_IDX                                  12
-#define SBK_QPLACEMANAGERENGINE_IDX                                  53
-#define SBK_QPLACEMANAGER_IDX                                        52
-#define SBK_QPLACEREPLY_IDX                                          58
-#define SBK_QPLACEREPLY_ERROR_IDX                                    59
-#define SBK_QPLACEREPLY_TYPE_IDX                                     60
-#define SBK_QPLACESEARCHSUGGESTIONREPLY_IDX                          67
-#define SBK_QPLACEMATCHREPLY_IDX                                     54
-#define SBK_QPLACEIDREPLY_IDX                                        49
-#define SBK_QPLACEIDREPLY_OPERATIONTYPE_IDX                          50
-#define SBK_QPLACEDETAILSREPLY_IDX                                   46
-#define SBK_QPLACECONTENTREPLY_IDX                                   44
-#define SBK_QPLACESEARCHREPLY_IDX                                    63
-#define SBK_QtLocation_IDX_COUNT                                     70
+#define SBK_QPLACEMANAGERENGINE_IDX                                  54
+#define SBK_QPLACEMANAGER_IDX                                        53
+#define SBK_QPLACEREPLY_IDX                                          59
+#define SBK_QPLACEREPLY_ERROR_IDX                                    60
+#define SBK_QPLACEREPLY_TYPE_IDX                                     61
+#define SBK_QPLACESEARCHSUGGESTIONREPLY_IDX                          69
+#define SBK_QPLACEMATCHREPLY_IDX                                     55
+#define SBK_QPLACEIDREPLY_IDX                                        50
+#define SBK_QPLACEIDREPLY_OPERATIONTYPE_IDX                          51
+#define SBK_QPLACEDETAILSREPLY_IDX                                   47
+#define SBK_QPLACECONTENTREPLY_IDX                                   45
+#define SBK_QPLACESEARCHREPLY_IDX                                    64
+#define SBK_QtLocation_IDX_COUNT                                     72
 
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtLocationTypes;
@@ -198,16 +200,16 @@ extern SbkConverter** SbkPySide2_QtLocationTypeConverters;
 #define SBK_QTLOCATION_QLIST_QPLACE_IDX                              1 // QList<QPlace >
 #define SBK_QTLOCATION_QLIST_QPLACESEARCHRESULT_IDX                  2 // const QList<QPlaceSearchResult > &
 #define SBK_QTLOCATION_QLIST_QPLACECONTACTDETAIL_IDX                 3 // QList<QPlaceContactDetail >
-#define SBK_QTLOCATION_QLIST_QGEOCOORDINATE_IDX                      4 // QList<QGeoCoordinate >
-#define SBK_QTLOCATION_QLIST_QGEORECTANGLE_IDX                       5 // QList<QGeoRectangle >
-#define SBK_QTLOCATION_QLIST_QGEOROUTEREQUEST_FEATURETYPE_IDX        6 // QList<QGeoRouteRequest::FeatureType >
-#define SBK_QTLOCATION_QLIST_QVARIANTMAP_IDX                         7 // const QList<QVariantMap > &
-#define SBK_QTLOCATION_QLIST_QOBJECTPTR_IDX                          8 // const QList<QObject* > &
-#define SBK_QTLOCATION_QLIST_QBYTEARRAY_IDX                          9 // QList<QByteArray >
-#define SBK_QTLOCATION_QLIST_QGEOROUTE_IDX                           10 // const QList<QGeoRoute > &
-#define SBK_QTLOCATION_QLIST_QGEOLOCATION_IDX                        11 // QList<QGeoLocation >
-#define SBK_QTLOCATION_QLIST_QLOCALE_IDX                             12 // QList<QLocale >
-#define SBK_QTLOCATION_QMAP_INT_QPLACECONTENT_IDX                    13 // QMap<int,QPlaceContent >
+#define SBK_QTLOCATION_QMAP_INT_QPLACECONTENT_IDX                    4 // QMap<int,QPlaceContent >
+#define SBK_QTLOCATION_QLIST_QGEOCOORDINATE_IDX                      5 // QList<QGeoCoordinate >
+#define SBK_QTLOCATION_QLIST_QGEORECTANGLE_IDX                       6 // QList<QGeoRectangle >
+#define SBK_QTLOCATION_QLIST_QGEOROUTEREQUEST_FEATURETYPE_IDX        7 // QList<QGeoRouteRequest::FeatureType >
+#define SBK_QTLOCATION_QLIST_QVARIANTMAP_IDX                         8 // const QList<QVariantMap > &
+#define SBK_QTLOCATION_QLIST_QOBJECTPTR_IDX                          9 // const QList<QObject* > &
+#define SBK_QTLOCATION_QLIST_QBYTEARRAY_IDX                          10 // QList<QByteArray >
+#define SBK_QTLOCATION_QLIST_QGEOROUTE_IDX                           11 // const QList<QGeoRoute > &
+#define SBK_QTLOCATION_QLIST_QGEOLOCATION_IDX                        12 // QList<QGeoLocation >
+#define SBK_QTLOCATION_QLIST_QLOCALE_IDX                             13 // QList<QLocale >
 #define SBK_QTLOCATION_QLIST_QVARIANT_IDX                            14 // QList<QVariant >
 #define SBK_QTLOCATION_QLIST_QSTRING_IDX                             15 // QList<QString >
 #define SBK_QTLOCATION_QMAP_QSTRING_QVARIANT_IDX                     16 // QMap<QString,QVariant >
@@ -223,6 +225,7 @@ template<> inline PyTypeObject* SbkType< ::QPlaceUser >() { return reinterpret_c
 template<> inline PyTypeObject* SbkType< ::QPlaceSearchRequest::RelevanceHint >() { return SbkPySide2_QtLocationTypes[SBK_QPLACESEARCHREQUEST_RELEVANCEHINT_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QPlaceSearchRequest >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtLocationTypes[SBK_QPLACESEARCHREQUEST_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QPlaceMatchRequest >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtLocationTypes[SBK_QPLACEMATCHREQUEST_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QPlaceSearchResult::SearchResultType >() { return SbkPySide2_QtLocationTypes[SBK_QPLACESEARCHRESULT_SEARCHRESULTTYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QPlaceSearchResult >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtLocationTypes[SBK_QPLACESEARCHRESULT_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QPlaceProposedSearchResult >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtLocationTypes[SBK_QPLACEPROPOSEDSEARCHRESULT_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QPlaceResult >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtLocationTypes[SBK_QPLACERESULT_IDX]); }
@@ -232,6 +235,7 @@ template<> inline PyTypeObject* SbkType< ::QPlace >() { return reinterpret_cast<
 template<> inline PyTypeObject* SbkType< ::QPlaceContactDetail >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtLocationTypes[SBK_QPLACECONTACTDETAIL_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QPlaceAttribute >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtLocationTypes[SBK_QPLACEATTRIBUTE_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QPlaceRatings >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtLocationTypes[SBK_QPLACERATINGS_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QPlaceContent::Type >() { return SbkPySide2_QtLocationTypes[SBK_QPLACECONTENT_TYPE_IDX]; }
 template<> inline PyTypeObject* SbkType< ::QPlaceContent >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtLocationTypes[SBK_QPLACECONTENT_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QPlaceReview >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtLocationTypes[SBK_QPLACEREVIEW_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QPlaceImage >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtLocationTypes[SBK_QPLACEIMAGE_IDX]); }
